# Generated by Django 1.11.7 on 2018-02-28 11:10

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [("djangocms_htmlsitemap", "0001_initial")]

    operations = [
        migrations.AlterField(
            model_name="htmlsitemappluginconf",
            name="cmsplugin_ptr",
            field=models.OneToOneField(
                auto_created=True,
                on_delete=django.db.models.deletion.CASCADE,
                parent_link=True,
                primary_key=True,
                related_name="djangocms_htmlsitemap_htmlsitemappluginconf",
                serialize=False,
                to="cms.CMSPlugin",
            ),
        )
    ]
